package com.magictale.luminardo;

import gueei.binding.app.BindingActivity;
import gueei.binding.observables.IntegerObservable;
import android.annotation.TargetApi;
import android.app.Activity;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.text.method.ScrollingMovementMethod;
import android.view.MotionEvent;
import android.view.View;
import android.content.Intent;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.widget.CompoundButton;
import android.widget.SeekBar;
import android.widget.SeekBar.*;
import android.widget.Switch;

import android.widget.TextView;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothSocket;

import com.gueei.example.colorPicker.ColorPicker;
import com.gueei.example.colorPicker.R;

import java.io.IOException;
import java.io.OutputStream;
import java.util.UUID;


public class LuminardoControlActivity extends BindingActivity
        implements ColorPicker.OnColorPickedListener
        {
    
	public final IntegerObservable Color = new IntegerObservable(android.graphics.Color.RED);

    private SeekBar horizSeekBar;
    private SeekBar vertSeekBar;
    private Switch pulseLEDSwitch;
    private ColorPicker picker;
    private static final int REQUEST_ENABLE_BT = 1;
    private BluetoothAdapter btAdapter = null;
    private BluetoothSocket btSocket = null;
    private OutputStream outStream = null;

    // Well known SPP UUID
    private static final UUID MY_UUID =
            UUID.fromString("00001101-0000-1000-8000-00805F9B34FB");

    // Insert your server's MAC address
    private static String address = "00:19:0E:12:65:6A"; //Targus Dongle
    //private static String address = "00:15:83:03:B1:B5"; //Rovermate Dongle

	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        this.setAndBindRootView(R.layout.main, this);

        horizSeekBar = (SeekBar) findViewById(R.id.horSeekBar);
        horizSeekBar.setOnSeekBarChangeListener(new OnSeekBarChangeListener() {
            int progressChanged = 0;

            public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser){
                progressChanged = progress;

                String message = "HorizSeekBar=" + progress + "\r\n";
                SendGenericCmd(message);
            }

            public void onStartTrackingTouch(SeekBar seekBar) {
            }

            public void onStopTrackingTouch(SeekBar seekBar) {
            }
        });

        vertSeekBar = (SeekBar) findViewById(R.id.verSeekBar);
        vertSeekBar.setOnSeekBarChangeListener(new OnSeekBarChangeListener() {
            int progressChanged = 0;

            public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser){
                progressChanged = progress;

                String message = "VertSeekBar=" + progress + "\r\n";
                SendGenericCmd(message);
            }

            public void onStartTrackingTouch(SeekBar seekBar) {
            }

            public void onStopTrackingTouch(SeekBar seekBar) {
            }
        });

        pulseLEDSwitch = (Switch) findViewById(R.id.pulseLEDSwitch);
        pulseLEDSwitch.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                int state = 0;
                if (isChecked) state = 1;
                String message = "PulseLEDSwitch=" + state + "\r\n";
                SendGenericCmd(message);
            }
        });

        picker = (ColorPicker) findViewById(R.id.colorPicker);
        picker.SetColorPickedListener(this);

        btAdapter = BluetoothAdapter.getDefaultAdapter();
        CheckBTState();
        ConnectBT();
    }

    private void CheckBTState() {
        // Check for Bluetooth support and then check to make sure it is turned on

        // Emulator doesn't support Bluetooth and will return null
        if(btAdapter==null) {
            AlertBox("Fatal Error", "Bluetooth Not supported. Aborting.");
        } else {
            if (btAdapter.isEnabled()) {
            } else {
                //Prompt user to turn on Bluetooth
                Intent enableBtIntent = new Intent(btAdapter.ACTION_REQUEST_ENABLE);
                startActivityForResult(enableBtIntent, REQUEST_ENABLE_BT);
            }
        }
    }

    public void AlertBox( String title, String message ){
        new AlertDialog.Builder(this)
                .setTitle( title )
                .setMessage( message + " Press OK to exit." )
                .setPositiveButton("OK", new OnClickListener() {
                    public void onClick(DialogInterface arg0, int arg1) {
                        //finish();
                    }
                }).show();
    }

    public void ConnectBT() {
        // Set up a pointer to the remote node using it's address.
        BluetoothDevice device = btAdapter.getRemoteDevice(address);

        // Two things are needed to make a connection:
        //   A MAC address, which we got above.
        //   A Service ID or UUID.  In this case we are using the
        //     UUID for SPP.
        try {
            btSocket = device.createRfcommSocketToServiceRecord(MY_UUID);
        } catch (IOException e) {
            AlertBox("Fatal Error", "In ConnectBT() and socket create failed: " + e.getMessage() + ".");
        }

        // Discovery is resource intensive.  Make sure it isn't going on
        // when you attempt to connect and pass your message.
        btAdapter.cancelDiscovery();

        // Establish the connection.  This will block until it connects.
        try {
            btSocket.connect();
        } catch (IOException e) {
            try {
                btSocket.close();
            } catch (IOException e2) {
                AlertBox("Fatal Error", "In ConnectBT() and unable to close socket during connection failure" + e2.getMessage() + ".");
            }
        }

        // Create a data stream so we can talk to server.
        try {
            outStream = btSocket.getOutputStream();
        } catch (IOException e) {
            AlertBox("Fatal Error", "In onResume() and output stream creation failed:" + e.getMessage() + ".");
        }

        String message = "Hello from Android Control.\n";
        byte[] msgBuffer = message.getBytes();
        try {
            outStream.write(msgBuffer);
        } catch (IOException e) {
            String msg = "In onResume() and an exception occurred during write: " + e.getMessage();
            if (address.equals("00:00:00:00:00:00"))
                msg = msg + ".\n\nUpdate your server address from 00:00:00:00:00:00 to the correct address on line 37 in the java code";
            msg = msg +  ".\n\nCheck that the SPP UUID: " + MY_UUID.toString() + " exists on server.\n\n";

            AlertBox("Fatal Error", msg);
        }
    }

    @Override
    public void onStop() {
        super.onStop();
        if (outStream != null) {
            try {
                outStream.flush();
            } catch (IOException e) {
                AlertBox("Fatal Error", "In onStop() and failed to flush output stream: " + e.getMessage() + ".");
            }
        }

        try     {
            btSocket.close();
        } catch (IOException e2) {
            AlertBox("Fatal Error", "In onStop() and failed to close socket." + e2.getMessage() + ".");
        }

    }

    @Override
    public void onDestroy() {
        super.onDestroy();
    }


    private void SendGenericCmd(String cmd)
    {
        String message = cmd;
        byte[] msgBuffer = message.getBytes();
        try {
            outStream.write(msgBuffer);
        } catch (IOException e) {
            AlertBox("Fatal Error", e.getMessage());
        }
    }

    public void OnBeepBtnClick(View view) {
        SendGenericCmd("Beep\r\n");
    }

    public void OnTimeBtnClick(View view) {
        SendGenericCmd("Time\r\n");
    }

    public void OnTempBtnClick(View view) {
        SendGenericCmd("Temp\r\n");
    }

    public void OnTxtBtn1Click(View view) {
        SendGenericCmd("TxtBtn1\r\n");
    }

    public void OnTxtBtn2Click(View view) {
        SendGenericCmd("TxtBtn2\r\n");
    }

    public void OnTxtBtn3Click(View view) {
        SendGenericCmd("TxtBtn3\r\n");
    }

    public void colorPicked(int color)
    {
        int red = android.graphics.Color.red(color);
        int green = android.graphics.Color.green(color);
        int blue = android.graphics.Color.blue(color);

        //AlertBox("Test", "Color: red=" + red + " green=" + green + " blue=" + blue);

        String message = "Color=R" + red + ",G" + green + ",B" + blue + "\r\n";
        SendGenericCmd(message);
    }

}